@@ -39,7 +39,7 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         self.quantities: List[Quantity] = list()
         self.times = None
         # List of all subslices this slice consists of (one per mesh).
-        self._subslices: List[_SubSlice] = list()
+        self._subslices: List[SubSlice] = list()
 
     def _add_subslice(self, filename: str, quantity: str, label: str, unit: str, extent: Extent,
                       mesh: Mesh):
@@ -62,16 +62,28 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             (('f', extent.size(cell_centered=self.cell_centered)),)))
 
         if self.times is None:
-            t_n = (os.stat(os.path.join(self.root_path, filename)).st_size - _SubSlice._offset) \
+            t_n = (os.stat(os.path.join(self.root_path, filename)).st_size - SubSlice._offset) \
                   // dtype_data.itemsize
             self.times = np.empty(shape=(t_n,))
             self.times[0] = -1
 
-        self._subslices.append(_SubSlice(filename, extent, quantity, mesh, self.times))
+        self._subslices.append(
+            SubSlice(filename, self.root_path, self.cell_centered, extent, quantity, mesh,
+                     self.times))
 
         # If lazy loading has been disabled by the user, load the data instantaneously instead
         if not settings.LAZY_LOAD:
-            self._subslices[-1].get_data(quantity, self.root_path, self.cell_centered)
+            self._subslices[-1].get_data(quantity)
+
+    def get_subslice(self, mesh: Mesh):
+        """
+        Returns the SubSlice that cuts through the given mesh.
+        :param mesh:
+        """
+        for slc in self._subslices:
+            if slc.mesh.id == mesh.id:
+                return slc
+        return None
 
     def mean(self, quantity: str = None):
         """
@@ -84,7 +96,7 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             quantity = self.quantities[0].quantity
         mean_sum = 0
         for subsclice in self._subslices:
-            mean_sum += np.mean(subsclice.get_data(quantity, self.root_path, self.cell_centered))
+            mean_sum += np.mean(subsclice.get_data(quantity))
         return mean_sum / len(self._subslices)
 
     def __array__(self):
@@ -118,7 +130,7 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
                                     q.quantity, q.label,
                                     q.unit, subslice.extent, subslice.mesh)
             new_slice._subslices[-1]._data[q.quantity] = ufunc(
-                subslice.get_data(q.quantity, self.root_path, self.cell_centered),
+                subslice.get_data(q.quantity),
                 input_list[0],
                 **kwargs)
         return new_slice
@@ -136,9 +148,11 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         return _HANDLED_FUNCTIONS[func](*args, **kwargs)
 
 
-class _SubSlice:
+class SubSlice:
     """
     Part of a slice that cuts through a single mesh.
+    :ivar root_path: Path to the directory containing the slice file.
+    :ivar cell_centered: Indicates whether centered positioning for data is used.
     :ivar mesh: The mesh the subslice cuts through.
     :ivar extent: Extent object containing 3-dimensional extent information.
     :ivar file_names: File names for the corresponding slice file depending on the quantity.
@@ -146,39 +160,41 @@ class _SubSlice:
 
     _offset = 3 * fdtype.new((('c', 30),)).itemsize + fdtype.new((('i', 6),)).itemsize
 
-    def __init__(self, filename: str, extent: Extent, quantity: str, mesh: Mesh, times):
+    def __init__(self, filename: str, root_path: str, cell_centered: bool, extent: Extent,
+                 quantity: str, mesh: Mesh, times):
         self.mesh = mesh
         self.extent = extent
+        self.root_path = root_path
+        self.cell_centered = cell_centered
 
         self.file_names = {quantity: filename}
         self._data: Dict[str, np.ndarray] = dict()  # Dictionary that maps quantity to data.
         self._times = times
 
-    def get_data(self, quantity: str, root_path: str, cell_centered: bool) -> np.ndarray:
+    def get_data(self, quantity: str) -> np.ndarray:
         """
-        Method to lazy load the slice's data.
-        :param quantity: Quantity of the data.
-        :param root_path: Path to the directory containing all slice files.
-        :param cell_centered: Indicates whether centered positioning for data is used.
+        Method to lazy load the slice's data for a specific quantity.
         """
         if quantity not in self._data:
-            file_path = os.path.join(root_path, self.file_names[quantity])
-            n = self.extent.size(cell_centered=cell_centered)
+            file_path = os.path.join(self.root_path, self.file_names[quantity])
+            n = self.extent.size(cell_centered=self.cell_centered)
+            shape = (self.extent.x - 1 if self.cell_centered else self.extent.x,
+                     self.extent.y - 1 if self.cell_centered else self.extent.y,
+                     self.extent.z - 1 if self.cell_centered else self.extent.z)
+
             dtype_data = fdtype.combine(fdtype.FLOAT, fdtype.new((('f', n),)))
 
             fill_times = self._times[0] == -1
             t_n = self._times.shape[0]
 
-            self._data[quantity] = np.empty((t_n, self.extent.x, self.extent.y, self.extent.z),
-                                            dtype=np.float32)
+            self._data[quantity] = np.empty((t_n,) + shape, dtype=np.float32)
 
             with open(file_path, 'rb') as infile:
                 infile.seek(self._offset)
                 for i, data in enumerate(fdtype.read(infile, dtype_data, t_n)):
                     if fill_times:
                         self._times[i] = data[0][0]
-                    self._data[quantity][i, :] = data[1].reshape(
-                        (self.extent.x, self.extent.y, self.extent.z))
+                    self._data[quantity][i, :] = data[1].reshape(shape)
         return self._data[quantity]
 
 
